@@ -297,9 +297,9 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
   if (psr->param[ip2].set1 == 1 && psr->param[ip3].set1 == 1)
     raDecCoords=2;
 
-  if (psr->param[ip4].set1 == 1 && psr->param[ip5].set1 == 1)
+  if (psr->param[ip4].set1 == 1 || psr->param[ip5].set1 == 1)
     pmCoords=1;
-  if (psr->param[ip8].set1 == 1 && psr->param[ip9].set1 == 1)
+  if (psr->param[ip8].set1 == 1 || psr->param[ip9].set1 == 1)
     pmCoords=2;
 
   for (i=0;i<npsr;i++)
@@ -352,12 +352,18 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
 			      if (raDecCoords == 1 && pmCoords==2) // Only show RA/DEC
 				{
 				  if (j == ip8 || j == ip9)
-				    showValue=0;
+				    {
+				      showValue=0;
+				      printf("# WARNING: mixed coordinates ignoring %s %s\n",pcat_parameters[j],dispParam.val);
+				    }
 				}
 			      else if (raDecCoords == 2 && pmCoords==1) // Only show ELAT/ELONG
 				{
-				  if (j == ip4 || j == ip5)
-				    showValue=0;
+		 		  if (j == ip4 || j == ip5)
+				    {
+				      showValue=0;
+				      printf("# WARNING: mixed coordinates ignoring %s %s\n",pcat_parameters[j],dispParam.val);
+				    }
 				}
 			    }
 			  if (showValue==1)
